@@ -9,7 +9,7 @@
 
 open Printf
 
-type arg = 
+type arg =
   | I of string (* check header file (#include) available (promoted to config) *)
   | T of string (* check type available *)
   | DEFINE of string (* define symbol prior to including header files (promoted to config) *)
@@ -42,6 +42,7 @@ let config_defines = [
   "_POSIX_C_SOURCE 200809L";
   "_XOPEN_SOURCE 700";
   "_BSD_SOURCE";
+  "_DARWIN_C_SOURCE";
   "_LARGEFILE64_SOURCE";
   "WIN32_LEAN_AND_MEAN";
   "_WIN32_WINNT 0x500";
@@ -59,6 +60,7 @@ let config_includes = [
   "caml/bigarray.h";
   "string.h";
   "errno.h";
+  "assert.h";
   ]
 
 let build_code args =
@@ -78,7 +80,7 @@ let build_code args =
     | D s -> pr "#ifndef %s" s; pr "#error %s not defined" s; pr "#endif"
     | S s -> pr "size_t var_%d = (size_t)&%s;" (fresh ()) s
     | V s -> pr "int var_%d = (0 == %s);" (fresh ()) s
-    | F (s,f) -> pr "size_t var_%d = (size_t)&((struct %s*)0)->%s" (fresh ()) s f
+    | F (s,f) -> pr "size_t var_%d = (size_t)&((struct %s*)0)->%s;" (fresh ()) s f
     end args;
   pr "int main() { return 0; }";
   Buffer.contents b
@@ -103,7 +105,7 @@ let discover (name,test) =
   let rec loop args other =
     let code = build_code args in
     match execute code, other with
-    | false, [] -> 
+    | false, [] ->
         if !verbose >= 2 then prerr_endline code;
         print_endline "failed"; NO name
     | false, (x::xs) -> loop x xs
@@ -121,8 +123,6 @@ let show_c file result =
   let b = Buffer.create 10 in
   let pr fmt = ksprintf (fun s -> Buffer.add_string b (s^"\n")) fmt in
   pr "";
-  pr "#define UNUSED(x) (void)(x)";
-  pr "";
   List.iter (print_define b) config_defines;
   List.iter begin function
     | NO _ -> ();
@@ -137,6 +137,7 @@ let show_c file result =
   end result;
   pr "";
   List.iter (print_include b) config_includes;
+  pr "#include \"common.h\"";
   List.iter begin function
     | NO name ->
       pr "";
@@ -160,17 +161,24 @@ let show_c file result =
 let show_ml file result =
   let ch = open_out file in
   let pr fmt = ksprintf (fun s -> output_string ch (s^"\n")) fmt in
-  pr "let have = function";
+  pr "(** @return whether feature is available *)";
+  pr "let feature = function";
   List.iter (function
   | YES (name,_) -> pr "| %S -> Some true" name
   | NO name -> pr "| %S -> Some false" name) result;
   pr "| _ -> None";
+  pr "";
+  pr "(** @return whether feature is available *)";
+  pr "let have = function";
+  List.iter (function
+  | YES (name,_) -> pr "| `%s -> true" name
+  | NO name -> pr "| `%s -> false" name) result;
   close_out ch
 
 let main config =
   let result = List.map discover config in
   show_c "src/config.h" result;
-  show_ml "src/config.ml" result
+  show_ml "src/extUnixConfig.ml" result
 
 let features =
   [
@@ -185,7 +193,7 @@ let features =
       I "sys/types.h"; I "sys/stat.h";
       I "unistd.h"; I "stdio.h";
       D "S_IFREG";
-      S "fstatat"; S "openat"; S "unlinkat"; S "renameat"; S "mkdirat"; S "linkat"; S "symlinkat"; S "readlinkat";
+      S "fstatat"; S "openat"; S "unlinkat"; S "renameat"; S "mkdirat"; S "linkat"; S "symlinkat"; S "readlinkat"; S "fchownat"; S "fchmodat";
     ];
     "DIRFD", L[
       I "sys/types.h";
@@ -231,7 +239,7 @@ let features =
       D "POSIX_FADV_NORMAL";
     ];
     "FALLOCATE", ANY[
-      [I "fcntl.h"; S "posix_fallocate"; S" posix_fallocate64"; ];
+      [I "fcntl.h"; S "posix_fallocate"; S "posix_fallocate64"; ];
       [D "WIN32"; S "GetFileSizeEx"; ];
     ];
     "TTY_IOCTL", L[
@@ -304,20 +312,26 @@ let features =
       S "sysconf";
       (* check for standard values and extensions *)
       D "_SC_VERSION"; D "_SC_2_VERSION";
-      D "_SC_PHYS_PAGES"; D "_SC_AVPHYS_PAGES"; D "_SC_NPROCESSORS_CONF"; D "_SC_NPROCESSORS_ONLN";
     ];
     "SPLICE", L[ I "fcntl.h"; S"splice"; ];
     "TEE", L[ I "fcntl.h"; S"tee"; ];
     "VMSPLICE", L[ I "fcntl.h"; S"vmsplice"; ];
     "SOCKOPT", L[
-      I "sys/socket.h"; I "netinet/in.h"; I "netinet/tcp.h";
+      I "sys/socket.h"; I "netinet/in.h"; I"netinet/tcp.h";
       S"setsockopt"; S"getsockopt";
-      V"TCP_KEEPCNT"; V"TCP_KEEPIDLE"; V"TCP_KEEPINTVL";
     ];
+    "TCP_KEEPCNT", L[I"netinet/in.h"; I"netinet/tcp.h";V"TCP_KEEPCNT"];
+    "TCP_KEEPIDLE", L[I"netinet/in.h"; I"netinet/tcp.h";V"TCP_KEEPIDLE"];
+    "TCP_KEEPINTVL", L[I"netinet/in.h"; I"netinet/tcp.h";V"TCP_KEEPINTVL"];
     "POLL", L[ I "poll.h"; S "poll"; D "POLLIN"; D "POLLOUT"; Z "POLLRDHUP" ];
+    "SYSINFO", L[ I"sys/sysinfo.h"; S"sysinfo"; F ("sysinfo","mem_unit")];
+    "MCHECK", L[ I"mcheck.h"; S"mtrace"; S"muntrace" ];
+    "MOUNT", L[ I"sys/mount.h"; S "mount"; S "umount2"; D "MS_REC" ];
+    "UNSHARE", L[ I"sched.h"; S "unshare"; D "CLONE_NEWPID"; D "CLONE_NEWUSER"];
+    "CHROOT", L[ I"unistd.h"; S "chroot"; ];
   ]
 
-let () = 
+let () =
   let args0 = [
     "-ocamlc", Arg.Set_string ocamlc, "<path> ocamlc";
     "-ext_obj", Arg.Set_string ext_obj, "<ext> C object files extension";
@@ -328,7 +342,7 @@ let () =
     assert (not (String.contains name ' '));
     "--disable-" ^ String.lowercase name,
     Arg.Unit (fun () -> disabled := name :: !disabled),
-    " disable " ^ name) features 
+    " disable " ^ name) features
   in
   let args = Arg.align (args0 @ args1) in
   Arg.parse args failwith ("Options are:");
